websweep.consolidator package
=============================

Submodules
----------

websweep.consolidator.consolidator module
-----------------------------------------

.. automodule:: websweep.consolidator.consolidator
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: websweep.consolidator
   :members:
   :show-inheritance:
   :undoc-members:
